@@ -30,12 +30,11 @@
 #include "vinagre-utils.h"
 #include "vinagre-connection.h"
 #include "vinagre-commands.h"
-#include "vinagre-plugin.h"
 #include "vinagre-plugins-engine.h"
 
 #include <config.h>
 
-#ifdef VINAGRE_ENABLE_AVAHI
+#ifdef VINAGRE_HAVE_AVAHI
 #include "vinagre-mdns.h"
 #endif
 
@@ -67,10 +66,7 @@ static void  vinagre_applet_init       (VinagreApplet *applet);
 static void	vinagre_applet_get_icon		(VinagreApplet *applet);
 static void	vinagre_applet_check_size	(VinagreApplet *applet);
 static gboolean	vinagre_applet_draw_cb		(VinagreApplet *applet);
-static void	vinagre_applet_update_tooltip	(VinagreApplet *applet);
-static void	vinagre_applet_dialog_about_cb	(BonoboUIComponent *uic, gpointer data, const gchar *verbname);
-static gboolean	vinagre_applet_bonobo_cb	(PanelApplet *_applet, const gchar *iid, gpointer data);
-static void	vinagre_applet_destroy_cb	(GtkObject *object);
+static void	vinagre_applet_destroy_cb	(GtkWidget     *widget);
 
 G_DEFINE_TYPE (VinagreApplet, vinagre_applet, PANEL_TYPE_APPLET)
 
@@ -142,19 +138,15 @@ vinagre_applet_check_size (VinagreApplet *applet)
 static gboolean
 vinagre_applet_draw_cb (VinagreApplet *applet)
 {
-  gint w, h, bg_type;
+  gint bg_type;
   GdkColor color;
-  GdkGC *gc;
   GdkPixmap *background;
-  GtkAllocation allocation;
   GdkWindow *window = gtk_widget_get_window (GTK_WIDGET (applet));
+  cairo_t *cr;
 
   if (window == NULL)
     return FALSE;
 
-  /* Clear the window so we can draw on it later */
-  gdk_window_clear (window);
-
   /* retrieve applet size */
   vinagre_applet_get_icon (applet);
   vinagre_applet_check_size (applet);
@@ -165,33 +157,27 @@ vinagre_applet_draw_cb (VinagreApplet *applet)
   if (applet->icon == NULL)
     return FALSE;
 
-  gtk_widget_get_allocation (GTK_WIDGET (applet), &allocation);
-  w = allocation.width;
-  h = allocation.height;
-
-  gc = gdk_gc_new (window);
+  cr = gdk_cairo_create (window);
 
   /* draw pixmap background */
   bg_type = panel_applet_get_background (PANEL_APPLET (applet), &color, &background);
   if (bg_type == PANEL_PIXMAP_BACKGROUND)
     {
       /* fill with given background pixmap */
-      gdk_draw_drawable (window, gc, background, 0, 0, 0, 0, w, h);
+      gdk_cairo_set_source_pixmap (cr, background, 0, 0);
+      cairo_paint (cr);
     }
-	
+
   /* draw color background */
   if (bg_type == PANEL_COLOR_BACKGROUND)
     {
-      gdk_gc_set_rgb_fg_color (gc,&color);
-      gdk_gc_set_fill (gc,GDK_SOLID);
-      gdk_draw_rectangle (window, gc, TRUE, 0, 0, w, h);
+      gdk_cairo_set_source_color (cr, &color);
+      cairo_fill (cr);
     }
 
-  /* draw icon at center */
-  gdk_draw_pixbuf (window, gc, applet->icon,
-		   0, 0, (w - applet->icon_width)/2, (h - applet->icon_height)/2,
-		   applet->icon_width, applet->icon_height,
-		   GDK_RGB_DITHER_NONE, 0, 0);
+  gdk_cairo_set_source_pixbuf (cr, applet->icon, 0, 0);
+  cairo_paint (cr);
+  cairo_destroy (cr);
 
   return TRUE;
 }
@@ -205,9 +191,9 @@ vinagre_applet_change_background_cb (VinagreApplet *applet,
 }
 
 static void
-vinagre_applet_destroy_cb (GtkObject *object)
+vinagre_applet_destroy_cb (GtkWidget *widget)
 {
-  VinagreApplet *applet = VINAGRE_APPLET (object);
+  VinagreApplet *applet = VINAGRE_APPLET (widget);
 
   if (applet->icon != NULL)
     g_object_unref (applet->icon);
@@ -301,7 +287,7 @@ fill_recursive_menu (GSList *entries, GtkWidget *menu)
     {
       VinagreBookmarksEntry *entry = VINAGRE_BOOKMARKS_ENTRY (l->data);
       VinagreConnection     *conn;
-      VinagrePlugin         *plugin;
+      VinagreProtocolExt    *ext;
 
       switch (vinagre_bookmarks_entry_get_node (entry))
 	{
@@ -322,10 +308,10 @@ fill_recursive_menu (GSList *entries, GtkWidget *menu)
 
 	  case VINAGRE_BOOKMARKS_ENTRY_NODE_CONN:
 	    conn = vinagre_bookmarks_entry_get_conn (entry);
-	    plugin = vinagre_plugins_engine_get_plugin_by_protocol (vinagre_plugins_engine_get_default (),
-								    vinagre_connection_get_protocol (conn));
+	    ext = vinagre_plugins_engine_get_plugin_by_protocol (vinagre_plugins_engine_get_default (),
+								 vinagre_connection_get_protocol (conn));
 
-	    image = gtk_image_new_from_icon_name (vinagre_plugin_get_icon_name (plugin),
+	    image = gtk_image_new_from_icon_name (vinagre_protocol_ext_get_icon_name (ext),
 						  GTK_ICON_SIZE_MENU);
 	    item = gtk_image_menu_item_new_with_label (vinagre_connection_get_name (conn));
 	    gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (item),
@@ -347,7 +333,7 @@ fill_recursive_menu (GSList *entries, GtkWidget *menu)
 static void
 fill_menu (GSList *all, GtkWidget *menu)
 {
-  GtkWidget *item, *image;
+  GtkWidget *item;
 
   if (g_slist_length (all) == 0)
     return;
@@ -396,7 +382,7 @@ vinagre_applet_click_cb (GtkWidget      *applet,
   all = vinagre_bookmarks_get_all (vinagre_bookmarks_get_default ());
   fill_menu (all, menu);
 
-#ifdef VINAGRE_ENABLE_AVAHI
+#ifdef VINAGRE_HAVE_AVAHI
   all = vinagre_mdns_get_all (vinagre_mdns_get_default ());
   fill_menu (all, menu);
 #endif
@@ -428,7 +414,7 @@ static void
 vinagre_applet_init (VinagreApplet *applet)
 {
   gchar *tmp;
-#ifdef VINAGRE_ENABLE_AVAHI
+#ifdef VINAGRE_HAVE_AVAHI
   VinagreMdns *mdns;
 #endif
 
@@ -471,7 +457,7 @@ vinagre_applet_init (VinagreApplet *applet)
   g_signal_connect (G_OBJECT (applet), "destroy",
 		    G_CALLBACK (vinagre_applet_destroy_cb), NULL);
 
-#ifdef VINAGRE_ENABLE_AVAHI
+#ifdef VINAGRE_HAVE_AVAHI
   mdns = vinagre_mdns_get_default ();
 #endif
 }
